@@ -1,7 +1,6 @@
 """
 The cLasses and functions that representing the Python Client.
 """
-import archipelagos.common.data
 from archipelagos.common.data import parse_timestamp_str
 from archipelagos.common.data.collection import CollectionMetadataRequest, CollectionMetadataResponse
 from archipelagos.common.data.collection import CollectionRequest, CollectionResponse
@@ -89,21 +88,26 @@ class Archipelagos:
     _test_user_api_key = 'test_user12345'
 
     @staticmethod
-    def setup_jupyter():
+    def setup_jupyter(install_geopandas: bool = False):
         """
         A convenience function that can be used to initialise a Jupyter Notebook (import Python packages, set sensible
         defaults for image sizes etc.) so that it can be used to run any example notebooks provided by the platform.
+
+        :param install_geopandas: True if geopandas should be installed, False otherwise.
+        :type install_geopandas: bool
         """
         # Import the packages typically required
 
-        import geopandas as gpd
+        if install_geopandas:
+            import geopandas as gpd
+
         import pandas as pd
         import matplotlib.pyplot as plt
 
         # Set any defaults typically required
 
         pd.options.mode.chained_assignment = None
-        plt.rcParams["figure.figsize"] = (20, 20)
+        plt.rcParams["figure.figsize"] = (15, 15)
         Archipelagos.api_key = Archipelagos._test_user_api_key
 
     @staticmethod
@@ -533,7 +537,12 @@ class Archipelagos:
                         data[date_time] = {}
 
                 columns = features if features is not None else list(features_returned.keys())
-                return pd.DataFrame.from_dict(data, orient='index', columns=columns)
+                df = pd.DataFrame.from_dict(data, orient='index', columns=columns)
+
+                # Add the metadata to the DataFrame
+
+                df.metadata = response.data.metadata
+                return df
 
         elif isinstance(response, CollectionResponse):
             if response.error_occurred:
