@@ -364,12 +364,12 @@ class TimeSeriesMetadata:
     @staticmethod
     def deserialize(serialized: bytes) -> TimeSeriesMetadata:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: The bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: TimeSeriesMetadata
         """
         metadata = TimeSeriesMetadata("a", "a", "a", "", "", "", dict(), Frequency.NONE, dict(), False, Timestamp.now(), Timestamp.now())
@@ -378,9 +378,9 @@ class TimeSeriesMetadata:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -503,7 +503,7 @@ class TimeSeriesMetadata:
         """
         Returns a bytes containing the state of this serialised.
 
-        :return: A str containing the state of this serialised.
+        :return: bytes containing the state of this serialised.
         :rtype: bytes
         """
         metadata = self._write_proto_object()
@@ -707,9 +707,9 @@ class TimeSeriesData:
     @staticmethod
     def deserialize(serialized: bytes) -> TimeSeriesData:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
         :return: A new instance using a str created by serialize().
@@ -722,9 +722,9 @@ class TimeSeriesData:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -811,7 +811,7 @@ class TimeSeriesData:
         """
         Returns a bytes containing the state of this serialised.
 
-        :return: A str containing the state of this serialised.
+        :return: bytes containing the state of this serialised.
         :rtype: bytes
         """
         time_series_data = self._write_proto_object()
@@ -887,12 +887,12 @@ class TimeSeries:
     @staticmethod
     def deserialize(serialized: bytes) -> TimeSeries:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: TimeSeries
         """
         metadata = TimeSeriesMetadata("a", "a", "a", "", "", "", dict(), Frequency.NONE, dict(), False,
@@ -904,9 +904,9 @@ class TimeSeries:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -945,7 +945,7 @@ class TimeSeries:
         """
         Returns a bytes containing the state of this serialised.
 
-        :return: A bytes containing the state of this serialised.
+        :return: bytes containing the state of this serialised.
         :rtype: bytes
         """
         time_series = self._write_proto_object()
@@ -1079,12 +1079,12 @@ class TimeSeriesMetadataRequest:
     @staticmethod
     def deserialize(serialized: bytes) -> TimeSeriesMetadataRequest:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: TimeSeriesMetadataRequest
         """
         request = TimeSeriesMetadataRequest("a", "a", "a", "a")
@@ -1093,9 +1093,9 @@ class TimeSeriesMetadataRequest:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1136,7 +1136,7 @@ class TimeSeriesMetadataRequest:
         """
         Returns a bytes containing the state of this serialised.
 
-        :return: A bytes containing the state of this serialised.
+        :return: bytes containing the state of this serialised.
         :rtype: bytes
         """
         request = self._write_proto_object()
@@ -1235,10 +1235,10 @@ class TimeSeriesMetadataResponse:
         """
         Creates a new instance using a str created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: TimeSeriesMetadataResponse
         """
         response = TimeSeriesMetadataResponse(error_code=0, error_message="")
@@ -1248,9 +1248,9 @@ class TimeSeriesMetadataResponse:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         response = TimeSeriesMetadataResponse_pb2.TimeSeriesMetadataResponse()
@@ -1299,7 +1299,7 @@ class TimeSeriesMetadataResponse:
         """
         Returns a bytes containing the state of this serialised.
 
-        :return: A bytes containing the state of this serialised.
+        :return: bytes containing the state of this serialised.
         :rtype: bytes
         """
         response = self._write_proto_object()
@@ -1561,10 +1561,10 @@ class TimeSeriesRequest:
         """
         Creates a new instance using a str created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: TimeSeriesRequest
         """
         request = TimeSeriesRequest("a", "a", "a", Timestamp.now(), Timestamp.now(), ["Example"], -1, True, {}, "a")
@@ -1573,9 +1573,9 @@ class TimeSeriesRequest:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1689,7 +1689,7 @@ class TimeSeriesRequest:
         """
         Returns a bytes containing the state of this serialised.
 
-        :return: A bytes containing the state of this serialised.
+        :return: bytes containing the state of this serialised.
         :rtype: bytes
         """
         request = self._write_proto_object()
@@ -1786,12 +1786,12 @@ class TimeSeriesResponse:
     @staticmethod
     def deserialize(serialized: bytes) -> TimeSeriesResponse:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: TimeSeriesResponse
         """
         response = TimeSeriesResponse(error_code=0, error_message="")
@@ -1800,9 +1800,9 @@ class TimeSeriesResponse:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         response = TimeSeriesResponse_pb2.TimeSeriesResponse()
@@ -1849,9 +1849,9 @@ class TimeSeriesResponse:
 
     def serialize(self) -> bytes:
         """
-        Returns a str containing the state of this serialised.
+        Returns bytes containing the state of this serialised.
 
-        :return: A str containing the state of this serialised.
+        :return: bytes containing the state of this serialised.
         :rtype: bytes
         """
         response = self._write_proto_object()
